@@ -58,13 +58,13 @@ class DingDingPlugin(NotificationPlugin):
         issue_data = requests.get(
             "http://web-middle.ruibogyl.work/sentry/findIssueTargetUrl",
             {"id": issue_id},
-            headers={"Content-Type": "application/json"}
+            headers={}
         ).json()
         print issue_data["data"]["url"]
         response = requests.get(
             "http://web-middle.ruibogyl.work/sentry/getDingDingAssignee",
             {"url": issue_data["data"]["url"]},
-            headers={"Content-Type": "application/json"}
+            headers={}
         ).json()
         print response["data"]["phone"]
         data = {
